sqlobject.inheritance package — SQLObject 3.9.1 documentation

# sqlobject.inheritance package

class `sqlobject.inheritance.` `InheritableSQLObject`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `SelectResultsClass`

    alias of `sqlobject.inheritance.InheritableSelectResults`

  `destroySelf`()
  classmethod `get`(id, connection=None, selectResults=None, childResults=None, childUpdate=False)
  `j` = inheritable_sql_object
  `q` = inheritable_sql_object
  classmethod `select`(clause=None, *args, **kwargs)
  classmethod `selectBy`(connection=None, **kw)
  `set`(**kw)
  `sqlmeta`

    alias of `sqlobject.inheritance.InheritableSQLMeta`

## Subpackages

- sqlobject.inheritance.tests package
  - Submodules
    - sqlobject.inheritance.tests.test_aggregates module
    - sqlobject.inheritance.tests.test_asdict module
    - sqlobject.inheritance.tests.test_deep_inheritance module
    - sqlobject.inheritance.tests.test_destroy_cascade module
    - sqlobject.inheritance.tests.test_foreignKey module
    - sqlobject.inheritance.tests.test_indexes module
    - sqlobject.inheritance.tests.test_inheritance module
    - sqlobject.inheritance.tests.test_inheritance_tree module

## Submodules

- sqlobject.inheritance.iteration module